%define         majornum        42
%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d
%define         srcname         libvips

Name:           vips
Version:        8.15.2
Release:        %mkrel 3
Summary:        A fast image processing library with low memory needs
License:        LGPLv2+
Group:          Graphics/Editors and Converters

URL:            https://www.libvips.org/
Source0:        https://github.com/libvips/libvips/releases/%{name}-%{version}.tar.xz

BuildRequires:  gtk-doc
BuildRequires:  glib-gettextize
BuildRequires:  meson
BuildRequires:  cmake
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(orc-0.4)
BuildRequires:  pkgconfig(matio)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(imagequant)
BuildRequires:  pkgconfig(libhwy)
BuildRequires:  pkgconfig(gobject-introspection-1.0)

Requires:       %{libname} = %{version}-%{release}

%description
Vips is a demand-driven, horizontally threaded image processing
library. Compared to similar libraries, libvips runs quickly and uses
little memory. libvips is licensed under the LGPL 2.1+. It has around
300 operations covering arithmetic, histograms, convolution,
morphological operations, frequency filtering, colour, resampling,
statistics and others. It supports a large range of numeric formats,
from 8-bit int to 128-bit complex. Images can have any number of
bands. It supports a good range of image formats, including JPEG,
TIFF, PNG, WebP, FITS, Matlab, OpenEXR, PDF, SVG, HDR, PPM, CSV, GIF,
Analyze, NIfTI, DeepZoom, and OpenSlide. It can also load images via
ImageMagick or GraphicsMagick, letting it load formats like DICOM.


%package -n %{libname}
License:        LGPLv2+
Summary:        A fast image processing library with low memory needs
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
Vips is a demand-driven, horizontally threaded image processing
library. Compared to similar libraries, libvips runs quickly and uses
little memory. libvips is licensed under the LGPL 2.1+. It has around
300 operations covering arithmetic, histograms, convolution,
morphological operations, frequency filtering, colour, resampling,
statistics and others. It supports a large range of numeric formats,
from 8-bit int to 128-bit complex. Images can have any number of
bands. It supports a good range of image formats, including JPEG,
TIFF, PNG, WebP, FITS, Matlab, OpenEXR, PDF, SVG, HDR, PPM, CSV, GIF,
Analyze, NIfTI, DeepZoom, and OpenSlide. It can also load images via
ImageMagick or GraphicsMagick, letting it load formats like DICOM.


%package -n %{develname}
License:        LGPLv2+
Summary:        Headers and modules for the vips library
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
Headers and modules for the vips library.


%prep

%setup -q -n %{name}-%{version}
%autopatch -p1


%build
%meson -Dcgif=disabled \
       -Dspng=disabled \
       -Dopenslide=disabled \
       -Dpdfium=disabled \
       -Dnifti=disabled

%meson_build


%install
%meson_install



#nuke la files from libtools
find %{buildroot}%{_libdir} -name *.la -delete
find %{buildroot}%{_libdir} -name *.a -delete

%find_lang %{name}8.15

%files -f %{name}8.15.lang
%doc ChangeLog README.md
#{_bindir}/batch_*
#{_bindir}/light_correct
#{_bindir}/shrink_width
%{_bindir}/vips*
%{_mandir}/man1/*.1*

%files -n %{libname}
%{_libdir}/libvips.so.%{majornum}{,.*}
%{_libdir}/libvips-cpp.so.%{majornum}{,.*}
#modules
%{_libdir}/vips-modules-8.15
%{_libdir}/girepository-1.0/*.typelib

%files -n %{develname}
%{_libdir}/libvips.so
%{_libdir}/libvips-cpp.so
%{_libdir}/pkgconfig/vips*.pc
%{_includedir}/vips
%{_datadir}/gir-1.0/*.gir


%changelog
* Fri Aug 30 2024 mrambo3501 <mrambo3501> 8.15.2-3.mga10
+ Revision: 2092205
- rebuild for new matio

* Fri Jul 05 2024 daviddavid <daviddavid> 8.15.2-2.mga10
+ Revision: 2079933
- rebuild for new libjxl 0.10.3

* Sun May 05 2024 eatdirt <eatdirt> 8.15.2-1.mga10
+ Revision: 2062212
- Update to version 8.15.2

* Tue Nov 07 2023 daviddavid <daviddavid> 8.13.3-4.mga10
+ Revision: 2005047
- rebuild for new libjxl 0.8.2

* Mon Jan 16 2023 daviddavid <daviddavid> 8.13.3-3.mga9
+ Revision: 1933663
- enable jpeg-xl support

* Mon Dec 12 2022 ns80 <ns80> 8.13.3-2.mga9
+ Revision: 1921143
- rebuild for new libtiff

* Sun Dec 04 2022 eatdirt <eatdirt> 8.13.3-1.mga9
+ Revision: 1917662
- Update to version 8.13.3

* Mon Oct 24 2022 eatdirt <eatdirt> 8.13.2-1.mga9
+ Revision: 1899037
- imported package vips

